translate.convert

Package translate :: Package convert |
[hide private]
[frames] | no frames]

# Package convert

source code

translate.convert is part of the translate package It contains code to convert between different storage formats for localizations

Submodules | [hide private]
translate.convert.factory: Factory methods to convert supported input files to supported translatable files.
XLIFF
translate.convert.odf2xliff: convert OpenDocument (ODF) files to XLIFF localization files translate.convert.oo2xliff: convert an OpenOffice.org (SDF) localization file to XLIFF localization files translate.convert.po2xliff: convert Gettext PO localization files to XLIFF localization files translate.convert.xliff2odf: convert OpenDocument (ODF) files to Gettext PO localization files translate.convert.xliff2oo: convert XLIFF localization files to an OpenOffice.org (SDF) localization file translate.convert.xliff2po: Convert XLIFF localization files to Gettext PO localization files.
Bilingual
translate.convert.csv2tbx: convert Comma-Separated Value (.csv) files to a TermBase eXchange (.tbx) glossary file translate.convert.oo2po: convert an OpenOffice.org (SDF) localization file to Gettext PO localization files translate.convert.po2oo: convert Gettext PO localization files to an OpenOffice.org (SDF) localization file translate.convert.po2tmx: convert Gettext PO localization files to a TMX (Translation Memory eXchange) file translate.convert.po2ts: convert Gettext PO localization files to Qt Linguist (.ts) files translate.convert.po2wordfast: convert Gettext PO localization files to a Wordfast translation memory file translate.convert.pot2po: Convert template files (like .pot or template .xlf files) translation files, preserving existing translations. translate.convert.ts2po: convert Qt Linguist (.ts) files to Gettext PO localization files
Monolingual
translate.convert.csv2po: convert Comma-Separated Value (.csv) files to Gettext PO localization files translate.convert.dtd2po: script to convert a mozilla .dtd UTF-8 localization format to a gettext .po localization file using the po and dtd modules, and the dtd2po convertor class which is in this module You can convert back to .dtd using po2dtd.py translate.convert.html2po: convert HTML files to Gettext PO localization files translate.convert.ical2po: convert iCal files to Gettext PO localization files translate.convert.ini2po: convert .ini files to Gettext PO localization files translate.convert.moz2po: convert Mozilla .dtd and .properties files to Gettext PO localization files translate.convert.mozfunny2prop: converts funny mozilla files to properties files translate.convert.php2po: convert PHP localization files to Gettext PO localization files translate.convert.po2csv: convert Gettext PO localization files to Comma-Separated Value (.csv) files translate.convert.po2dtd: script that converts a .po file to a UTF-8 encoded .dtd file as used by mozilla either done using a template or just using the .po file translate.convert.po2html: convert Gettext PO localization files to HTML files translate.convert.po2ical: convert Gettext PO localization files to iCal files translate.convert.po2ini: convert Gettext PO localization files to .ini files translate.convert.po2moz: convert Gettext PO localization files to Mozilla .dtd and .properties files translate.convert.po2php: convert Gettext PO localization files to PHP localization files translate.convert.po2prop: convert Gettext PO localization files to Java/Mozilla .properties files translate.convert.po2rc: Convert Gettext PO localization files back to Windows Resource (.rc) files translate.convert.po2sub: Convert Gettext PO localization files to subtitle files translate.convert.po2symb: convert Gettext PO localization files to Symbian translation files. translate.convert.po2tiki: Convert .po files to TikiWiki's language.php files. translate.convert.po2txt: convert Gettext PO localization files to plain text (.txt) files translate.convert.po2web2py: convert GNU/gettext PO files to web2py translation dictionaries (.py) translate.convert.prop2mozfunny: converts properties files back to funny mozilla files translate.convert.prop2po: convert Java/Mozilla .properties files to Gettext PO localization files translate.convert.rc2po: convert .rc files to Gettext PO localization files translate.convert.sub2po: convert subtitle files to Gettext PO localization files translate.convert.symb2po: Convert Symbian localisation files to Gettext PO localization files. translate.convert.tiki2po: Convert TikiWiki's language.php files to GetText PO files. translate.convert.txt2po: convert plain text (.txt) files to Gettext PO localization files translate.convert.web2py2po: convert web2py translation dictionaries (.py) to GNU/gettext PO files
Support
translate.convert.accesskey: functions used to manipulate access keys in strings translate.convert.convert: Handles converting of files between formats (used by translate.convert tools)
Other
translate.convert.poreplace: simple script to do replacements on translated strings inside po files